You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@oltu.apache.org by si...@apache.org on 2010/07/05 12:52:55 UTC

svn commit: r960538 - /incubator/amber/trunk/spec-api/src/main/java/org/apache/amber/signature/Key.java

Author: simonetripodi
Date: Mon Jul  5 10:52:55 2010
New Revision: 960538

URL: http://svn.apache.org/viewvc?rev=960538&view=rev
Log:
the same key can be used to sign the request with more than one algorithm, ie the same key is valid for PLAINTEXT and HMAC_SHA1 

Modified:
    incubator/amber/trunk/spec-api/src/main/java/org/apache/amber/signature/Key.java

Modified: incubator/amber/trunk/spec-api/src/main/java/org/apache/amber/signature/Key.java
URL: http://svn.apache.org/viewvc/incubator/amber/trunk/spec-api/src/main/java/org/apache/amber/signature/Key.java?rev=960538&r1=960537&r2=960538&view=diff
==============================================================================
--- incubator/amber/trunk/spec-api/src/main/java/org/apache/amber/signature/Key.java (original)
+++ incubator/amber/trunk/spec-api/src/main/java/org/apache/amber/signature/Key.java Mon Jul  5 10:52:55 2010
@@ -24,11 +24,11 @@ package org.apache.amber.signature;
 interface Key {
 
     /**
      * Returns the signing algorithm method.
      *
      * @return the signing algorithm method.
      */
-    String getAlgorithmMethod();
+    String[] getAlgorithmMethods();
 
     /**
      * Returns the key string representation.
@@ -24,11 +24,11 @@ package org.apache.amber.signature;
 
     /**
-     * Returns the signing algorithm method.
+     * Returns the signing algorithm methods.
      *
@@ -24,11 +24,11 @@ package org.apache.amber.signature;
      *
-     * @return the signing algorithm method.
+     * @return the signing algorithm methods.
      */